@@ -336,6 +336,41 @@ impl EnterpriseMatrixParser {
             let _d = items
                 .as_object()
                 .expect("Unable to Deserialize into String");
+            // Extract Required Permissions
+            if _d.contains_key("x_mitre_permissions_required") {
+                let mut _permissions = String::from("");
+                for _permission in items["x_mitre_permissions_required"]
+                                                                .as_array()
+                                                                .expect("Deserializing Mitre Permissions Issue")
+                {
+                    _permissions.push_str(&_permission
+                                            .as_str()
+                                            .unwrap()
+                                            .to_lowercase()
+                                            .replace("\\","-")
+                                            .replace(" ", ""));
+                    _permissions.push_str("|");
+                }
+                _permissions.pop();
+                _et.technique_required_permissions = _permissions;
+            }
+            if _d.contains_key("x_mitre_effective_permissions") {
+                let mut _permissions = String::from("");
+                for _permission in items["x_mitre_effective_permissions"]
+                                                                .as_array()
+                                                                .expect("Deserializing Mitre Permissions Issue")
+                {
+                    _permissions.push_str(&_permission
+                                            .as_str()
+                                            .unwrap()
+                                            .to_lowercase()
+                                            .replace("\\","-")
+                                            .replace(" ", ""));
+                    _permissions.push_str("|");
+                }
+                _permissions.pop();
+                _et.technique_effective_permissions = _permissions;
+            }
             // Extract Data Sources
             // Normalize the Data Source
             if _d.contains_key("x_mitre_data_sources") {
