@@ -27,6 +27,9 @@ pub struct EnterpriseMatrixStatistics {
     pub count_techniques_office365:         usize,
     pub count_techniques_saas:              usize,
     pub count_techniques_windows:           usize,
+    pub count_techniques_iaas:              usize,
+    pub count_techniques_containers:        usize,
+    pub count_techniques_google_workspace:  usize,
     // Count of Subtechniques by Platforms
     // Use these with stats functions
     pub count_subtechniques_aws:            usize,
@@ -38,6 +41,9 @@ pub struct EnterpriseMatrixStatistics {
     pub count_subtechniques_office365:      usize,
     pub count_subtechniques_saas:           usize,
     pub count_subtechniques_windows:        usize,
+    pub count_subtechniques_iaas:           usize,
+    pub count_subtechniques_containers:     usize,
+    pub count_subtechniques_google_workspace:  usize,
     // Count of Techniques by Tactic - KilChain
     // Use these with stats functions
     pub count_techniques_reconnaissance:     usize,
@@ -88,6 +94,9 @@ pub struct EnterpriseMatrixStatistics {
     pub percent_techniques_office365:  String,
     pub percent_techniques_saas:        String,
     pub percent_techniques_windows:     String,
+    pub percent_techniques_iaas:        String,
+    pub percent_techniques_google_workspace: String,
+    pub percent_techniques_containers:  String,
     // Percentage Subtechniques By Platform
     pub percent_subtechniques_aws:      String,
     pub percent_subtechniques_azure:    String,
@@ -98,6 +107,9 @@ pub struct EnterpriseMatrixStatistics {
     pub percent_subtechniques_office365: String,
     pub percent_subtechniques_saas:     String,
     pub percent_subtechniques_windows:  String,
+    pub percent_subtechniques_iaas:     String,
+    pub percent_subtechniques_google_workspace: String,
+    pub percent_subtechniques_containers:  String,
     // Percentage Techniques By KillChain/Tactic
     pub percent_techniques_reconnaissance:           String,
     pub percent_techniques_resource_development:    String,
@@ -154,6 +166,9 @@ impl EnterpriseMatrixStatistics {
             count_techniques_office365:         0,
             count_techniques_saas:              0,
             count_techniques_windows:           0,
+            count_techniques_google_workspace:  0,
+            count_techniques_iaas:              0,
+            count_techniques_containers:        0,
             count_subtechniques_aws:            0,
             count_subtechniques_azure:          0,
             count_subtechniques_azure_ad:       0,
@@ -163,6 +178,9 @@ impl EnterpriseMatrixStatistics {
             count_subtechniques_office365:      0,
             count_subtechniques_saas:           0,
             count_subtechniques_windows:        0,
+            count_subtechniques_google_workspace:  0,
+            count_subtechniques_iaas:              0,
+            count_subtechniques_containers:        0,
             count_techniques_reconnaissance:     0,
             count_techniques_resource_development: 0,
             count_techniques_initial_access:    0,
@@ -202,6 +220,9 @@ impl EnterpriseMatrixStatistics {
             percent_techniques_office365:   String::from(""),
             percent_techniques_saas:         String::from(""),
             percent_techniques_windows:      String::from(""),
+            percent_techniques_iaas:        String::from(""),
+            percent_techniques_containers:  String::from(""),
+            percent_techniques_google_workspace: String::from(""),
             // Percentage Subtechniques By Platform            
             percent_subtechniques_aws:          String::from(""),
             percent_subtechniques_azure:        String::from(""),
@@ -212,6 +233,9 @@ impl EnterpriseMatrixStatistics {
             percent_subtechniques_office365:    String::from(""),
             percent_subtechniques_saas:         String::from(""),
             percent_subtechniques_windows:      String::from(""),
+            percent_subtechniques_iaas:        String::from(""),
+            percent_subtechniques_containers:  String::from(""),
+            percent_subtechniques_google_workspace: String::from(""),
             // Percentage Technique By KillChain
             percent_techniques_reconnaissance:          String::from(""),
             percent_techniques_resource_development:    String::from(""),
@@ -286,6 +310,8 @@ pub struct EnterpriseTechnique {
     pub correlation_gid: String,
     pub technique_description: String,
     pub technique_references: Vec<EnterpriseTechniqueReference>,
+    pub technique_required_permissions: String,
+    pub technique_effective_permissions: String,
     pub search_token: String
     //pub correlation_mid: String,
     //pub correlation_tid: String,
@@ -312,6 +338,8 @@ impl EnterpriseTechnique {
             technique_description: "none".to_string(),
             technique_references: vec![],
             search_token: "none".to_string(),
+            technique_required_permissions: "none".to_string(),
+            technique_effective_permissions: "none".to_string()
             //correlation_mid: "none".to_string(),
            //correlation_tid: "none".to_string()
         }
@@ -519,7 +547,7 @@ impl EnterpriseProfileEntry {
 }
 
 
-#[derive(Debug, Deserialize, Serialize, Hash, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Debug, Deserialize, Serialize, Hash, Eq, PartialEq, Ord, PartialOrd, Clone)]
 pub struct EnterpriseTool {
     pub id:         String,
     pub name:       String,
@@ -550,7 +578,7 @@ impl EnterpriseTool {
 }
 
 
-#[derive(Debug, Deserialize, Serialize, Hash, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Debug, Deserialize, Serialize, Hash, Eq, PartialEq, Ord, PartialOrd, Clone)]
 pub struct EnterpriseToolProfile {
     pub tactics:        EnterpriseProfileEntry,
     pub techniques:     EnterpriseProfileEntry,
